##  Using the Roadmap Reports
Roadmap Report is configurable and can be set to any of the Fact Sheet types present in the workspace data model. A Project Roadmap Report, for instance, helps you keep track of your initiatives and projects. You can update it regularly to see progress and find new opportunities to improve your IT.
You can look at it in different ways - for example, in a Project Roadmap Report, you can get an overall picture or pay attention to particular details by switching between the Expanded and Collapsed views. In case you want to collapse or expand specific Projects, you can click on the toggle icon positioned on the left of the respective project. Furthermore, you can select the Zoom drop-down menu to adjust the timeframe and observe progress over various periods such as weeks, months, quarters, or years.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274de02f7a4410148385b635de71d74f_LowRes.png)
Additionally, you can customize the duration of the timeline and track advancement across different time span to meet your specific requirements by entering the start and end dates in the Report Settings.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27558ece7a441014b62a8fc9f7cbb373_LowRes.png)
From the same Report Settings, to better organize your roadmap, you can choose to cluster items in the roadmap by Relations (e.g., Applications, Providers, etc.), Fields (e.g., Technical Fit, etc.), or even tags.
Similarly, you can enable drill-downs for your timeline items to expand Applications, Projects, or IT Components into their related Fact Sheets (e.g., drill down from Applications to see their underlying IT Components). Here in the below example, you can see the projects clustered by Business capabilities and drilled down to the IT Components level.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274f24f37a441014b48dce0c31d4bb31_LowRes.png)
More relevant data from Fact Sheets, such as Tags, Subscription Roles, and Fields, can be added to Roadmap reports to improve decision-making and status reporting. The data to be shown can be chosen on the fly in the report settings. It lets you create multiple perspectives to understand better the situation and how it will change in the future. You can tidy up the report by hiding Fact Sheets that are not within the report's timeline. By checking the box to enable this feature, any Fact Sheets without a lifecycle falling within the visible or specified timeframe will be hidden.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27447f497a441014be5fb07f82369dd9_LowRes.png)
**Tip**
Displaying Additional Data: The new update in the Roadmap report now allows the users to display additional data which helps enrich the context, increases collaboration and interactivity of the report. Find more information in the section below.
Bringing these extra details to the Roadmap Report, for example, can help answer questions such as: Who's responsible for the migration of a particular Application, which is currently hosted on-premise, has an insufficient functional fit, and will reach the end-of-life in a few months? etc.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio9cca964964984b0797f67a8d44255867_LowRes.png)
